svn commit: r237593 - head/sys/dev/ath

2012-06-26 Thread Adrian Chadd
Author: adrian
Date: Tue Jun 26 07:56:15 2012
New Revision: 237593
URL: http://svn.freebsd.org/changeset/base/237593

Log:
  Make sure the BAR TX session pause is correctly unpaused when a node
  is reassociating.
  
  PR:   kern/169432

Modified:
  head/sys/dev/ath/if_ath_tx.c

Modified: head/sys/dev/ath/if_ath_tx.c
==
--- head/sys/dev/ath/if_ath_tx.cTue Jun 26 06:02:43 2012
(r237592)
+++ head/sys/dev/ath/if_ath_tx.cTue Jun 26 07:56:15 2012
(r237593)
@@ -4330,6 +4330,9 @@ ath_addba_response(struct ieee80211_node
 
 /*
  * Stop ADDBA on a queue.
+ *
+ * This can be called whilst BAR TX is currently active on the queue,
+ * so make sure this is unblocked before continuing.
  */
 void
 ath_addba_stop(struct ieee80211_node *ni, struct ieee80211_tx_ampdu *tap)
@@ -4341,9 +4344,21 @@ ath_addba_stop(struct ieee80211_node *ni
 
DPRINTF(sc, ATH_DEBUG_SW_TX_CTRL, "%s: called\n", __func__);
 
-   /* Pause TID traffic early, so there aren't any races */
+   /*
+* Pause TID traffic early, so there aren't any races
+* Unblock the pending BAR held traffic, if it's currently paused.
+*/
ATH_TXQ_LOCK(sc->sc_ac2q[atid->ac]);
ath_tx_tid_pause(sc, atid);
+   if (atid->bar_wait) {
+   /*
+* bar_unsuspend() expects bar_tx == 1, as it should be
+* called from the TX completion path.  This quietens
+* the warning.  It's cleared for us anyway.
+*/
+   atid->bar_tx = 1;
+   ath_tx_tid_bar_unsuspend(sc, atid);
+   }
ATH_TXQ_UNLOCK(sc->sc_ac2q[atid->ac]);
 
/* There's no need to hold the TXQ lock here */
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r237412 - in head: sys/contrib/dev/acpica sys/contrib/dev/acpica/common sys/contrib/dev/acpica/compiler sys/contrib/dev/acpica/components/debugger sys/contrib/dev/acpica/components/dis

2012-06-26 Thread Dimitry Andric
On 2012-06-25 23:37, Jung-uk Kim wrote:
...
> I submitted this patch and I am waiting for confirmation:
> 
> http://people.freebsd.org/~jkim/evxfgpe.diff

I've tested your diff, and it made the panic disappear for me.  Thanks!
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237601 - in head: share/examples/scsi_target sys/cam/ctl sys/dev/aic7xxx sys/dev/firewire sys/dev/mpt

2012-06-26 Thread Kenneth D. Merry
Author: ken
Date: Tue Jun 26 14:51:35 2012
New Revision: 237601
URL: http://svn.freebsd.org/changeset/base/237601

Log:
  Fix an issue that caused the kernel to panic inside CTL when trying
  to attach to target capable HBAs that implement the old immediate
  notify (XPT_IMMED_NOTIFY) and notify acknowledge (XPT_NOTIFY_ACK)
  CCBs.  The new API has been in place since SVN change 196008 in
  2009.
  
  The solution is two-fold:  fix CTL to handle the responses from the
  HBAs, and convert the HBA drivers in question to use the new API.
  
  These drivers have not been tested with CTL, so how well they will
  interoperate with CTL is unknown.
  
  scsi_target.c:Update the userland target example code to use the
new immediate notify API.
  
  scsi_ctl.c:   Detect when an immediate notify CCB is returned
with CAM_REQ_INVALID or CAM_PROVIDE_FAIL status,
and just free it.
  
Fix a duplicate assignment.
  
  aic79xx.c,
  aic79xx_osm.c:Update the aic79xx driver to use the new API.
Target mode is not enabled on for this driver, so
the changes will have no practical effect.
  
  aic7xxx.c,
  aic7xxx_osm.c:Update the aic7xxx driver to use the new API.
  
  sbp_targ.c:   Update the firewire target code to work with the
new API.
  
  mpt_cam.c:Update the mpt(4) driver to work with the new API.
Target mode is only enabled for Fibre Channel
mpt(4) devices.
  
  MFC after:3 days

Modified:
  head/share/examples/scsi_target/scsi_target.c
  head/sys/cam/ctl/scsi_ctl.c
  head/sys/dev/aic7xxx/aic79xx.c
  head/sys/dev/aic7xxx/aic79xx_osm.c
  head/sys/dev/aic7xxx/aic7xxx.c
  head/sys/dev/aic7xxx/aic7xxx_osm.c
  head/sys/dev/firewire/sbp_targ.c
  head/sys/dev/mpt/mpt_cam.c

Modified: head/share/examples/scsi_target/scsi_target.c
==
--- head/share/examples/scsi_target/scsi_target.c   Tue Jun 26 11:13:58 
2012(r237600)
+++ head/share/examples/scsi_target/scsi_target.c   Tue Jun 26 14:51:35 
2012(r237601)
@@ -88,7 +88,7 @@ static void   handle_read(void);
 /* static int  work_atio(struct ccb_accept_tio *); */
 static voidqueue_io(struct ccb_scsiio *);
 static int run_queue(struct ccb_accept_tio *);
-static int work_inot(struct ccb_immed_notify *);
+static int work_inot(struct ccb_immediate_notify *);
 static struct ccb_scsiio *
get_ctio(void);
 /* static void free_ccb(union ccb *); */
@@ -387,7 +387,7 @@ init_ccbs()
warn("malloc INOT");
return (-1);
}
-   inot->ccb_h.func_code = XPT_IMMED_NOTIFY;
+   inot->ccb_h.func_code = XPT_IMMEDIATE_NOTIFY;
send_ccb((union ccb *)inot, /*priority*/1);
}
 
@@ -495,8 +495,8 @@ request_loop()
/* Start one more transfer. */
retval = work_atio(&ccb->atio);
break;
-   case XPT_IMMED_NOTIFY:
-   retval = work_inot(&ccb->cin);
+   case XPT_IMMEDIATE_NOTIFY:
+   retval = work_inot(&ccb->cin1);
break;
default:
warnx("Unhandled ccb type %#x on workq",
@@ -651,7 +651,7 @@ work_atio(struct ccb_accept_tio *atio)
warnx("ATIO with %u bytes sense received",
  atio->sense_len);
}
-   sense = &atio->sense_data;
+   sense = (struct scsi_sense_data_fixed *)&atio->sense_data;
tcmd_sense(ctio->init_id, ctio, sense->flags,
   sense->add_sense_code, sense->add_sense_code_qual);
send_ccb((union ccb *)ctio, /*priority*/1);
@@ -772,16 +772,14 @@ run_queue(struct ccb_accept_tio *atio)
 }
 
 static int
-work_inot(struct ccb_immed_notify *inot)
+work_inot(struct ccb_immediate_notify *inot)
 {
cam_status status;
-   int sense;
 
if (debug)
warnx("Working on INOT %p", inot);
 
status = inot->ccb_h.status;
-   sense = (status & CAM_AUTOSNS_VALID) != 0;
status &= CAM_STATUS_MASK;
 
switch (status) {
@@ -794,7 +792,7 @@ work_inot(struct ccb_immed_notify *inot)
abort_all_pending();
break;
case CAM_MESSAGE_RECV:
-   switch (inot->message_args[0]) {
+   switch (inot->arg) {
case MSG_TASK_COMPLETE:
case MSG_INITIATOR_DET_ERR:
case MSG_ABORT_TASK_SET:
@@ -805,7 +803,7 @@ work_inot(struct ccb_immed_notify *inot)
case MSG_ABORT_TASK:
case

svn commit: r237604 - head/sys/amd64/amd64

2012-06-26 Thread Alan Cox
Author: alc
Date: Tue Jun 26 16:45:18 2012
New Revision: 237604
URL: http://svn.freebsd.org/changeset/base/237604

Log:
  Introduce RELEASE_PV_LIST_LOCK().

Modified:
  head/sys/amd64/amd64/pmap.c

Modified: head/sys/amd64/amd64/pmap.c
==
--- head/sys/amd64/amd64/pmap.c Tue Jun 26 15:30:35 2012(r237603)
+++ head/sys/amd64/amd64/pmap.c Tue Jun 26 16:45:18 2012(r237604)
@@ -189,6 +189,15 @@ __FBSDID("$FreeBSD$");
 #defineCHANGE_PV_LIST_LOCK_TO_VM_PAGE(lockp, m)\
CHANGE_PV_LIST_LOCK_TO_PHYS(lockp, VM_PAGE_TO_PHYS(m))
 
+#defineRELEASE_PV_LIST_LOCK(lockp) do {\
+   struct rwlock **_lockp = (lockp);   \
+   \
+   if (*_lockp != NULL) {  \
+   rw_wunlock(*_lockp);\
+   *_lockp = NULL; \
+   }   \
+} while (0)
+
 #defineVM_PAGE_TO_PV_LIST_LOCK(m)  \
PHYS_TO_PV_LIST_LOCK(VM_PAGE_TO_PHYS(m))
 
@@ -1714,10 +1723,7 @@ _pmap_allocpte(pmap_t pmap, vm_pindex_t 
if ((m = vm_page_alloc(NULL, ptepindex, VM_ALLOC_NOOBJ |
VM_ALLOC_WIRED | VM_ALLOC_ZERO)) == NULL) {
if (lockp != NULL) {
-   if (*lockp != NULL) {
-   rw_wunlock(*lockp);
-   *lockp = NULL;
-   }
+   RELEASE_PV_LIST_LOCK(lockp);
PMAP_UNLOCK(pmap);
rw_runlock(&pvh_global_lock);
VM_WAIT;
@@ -2133,10 +2139,7 @@ reclaim_pv_chunk(pmap_t locked_pmap, str
pmap = pc->pc_pmap;
/* Avoid deadlock and lock recursion. */
if (pmap > locked_pmap) {
-   if (*lockp != NULL) {
-   rw_wunlock(*lockp);
-   *lockp = NULL;
-   }
+   RELEASE_PV_LIST_LOCK(lockp);
PMAP_LOCK(pmap);
} else if (pmap != locked_pmap &&
!PMAP_TRYLOCK(pmap)) {
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237605 - in head/sys: dev/nand modules/nand

2012-06-26 Thread Takanori Watanabe
Author: takawata
Date: Tue Jun 26 18:08:03 2012
New Revision: 237605
URL: http://svn.freebsd.org/changeset/base/237605

Log:
  Add nand core module and module dependency information.
  
  Reviewed by:gber

Added:
  head/sys/modules/nand/
  head/sys/modules/nand/Makefile   (contents, props changed)
Modified:
  head/sys/dev/nand/nand.c
  head/sys/dev/nand/nandsim.c

Modified: head/sys/dev/nand/nand.c
==
--- head/sys/dev/nand/nand.cTue Jun 26 16:45:18 2012(r237604)
+++ head/sys/dev/nand/nand.cTue Jun 26 18:08:03 2012(r237605)
@@ -830,3 +830,5 @@ nand_erase_blocks(struct nand_chip *chip
 
return (err);
 }
+
+MODULE_VERSION(nand, 1);

Modified: head/sys/dev/nand/nandsim.c
==
--- head/sys/dev/nand/nandsim.c Tue Jun 26 16:45:18 2012(r237604)
+++ head/sys/dev/nand/nandsim.c Tue Jun 26 18:08:03 2012(r237605)
@@ -663,3 +663,5 @@ nandsim_modevent(module_t mod __unused, 
 
 DEV_MODULE(nandsim, nandsim_modevent, NULL);
 MODULE_VERSION(nandsim, 1);
+MODULE_DEPEND(nandsim, nand, 1, 1, 1);
+MODULE_DEPEND(nandsim, alq, 1, 1, 1);

Added: head/sys/modules/nand/Makefile
==
--- /dev/null   00:00:00 1970   (empty, because file is newly added)
+++ head/sys/modules/nand/Makefile  Tue Jun 26 18:08:03 2012
(r237605)
@@ -0,0 +1,13 @@
+# $FreeBSD$
+
+.PATH: ${.CURDIR}/../../dev/nand
+
+KMOD = nand
+SRCS=  nand.c nand_bbt.c nand_cdev.c nand_generic.c nand_geom.c \
+   nand_id.c nandbus.c nandbus_if.c nand_if.c nfc_if.c \
+   nand_if.h device_if.h bus_if.h nfc_if.h nandbus_if.h
+
+MFILES=kern/bus_if.m kern/device_if.m dev/nand/nfc_if.m \
+   dev/nand/nand_if.m dev/nand/nandbus_if.m
+
+.include 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r237008 - head/sys/dev/pci

2012-06-26 Thread Marius Strobl
On Mon, Jun 25, 2012 at 02:24:24PM -0400, John Baldwin wrote:
> On Monday, June 25, 2012 1:08:11 pm Marius Strobl wrote:
> > On Mon, Jun 25, 2012 at 10:00:08AM -0400, John Baldwin wrote:
> > > On Saturday, June 23, 2012 6:16:26 pm Marius Strobl wrote:
> > > > On Wed, Jun 13, 2012 at 03:04:50PM +, John Baldwin wrote:
> > > > > Author: jhb
> > > > > Date: Wed Jun 13 15:04:50 2012
> > > > > New Revision: 237008
> > > > > URL: http://svn.freebsd.org/changeset/base/237008
> > > > > 
> > > > > Log:
> > > > >   Fix a couple of bugs that prevented windows in PCI-PCI bridges from
> > > > >   growing "downward" (moving the start address down).  First, an off 
> > > > > by
> > > > >   one error caused the end address to be moved down an extra alignment
> > > > >   chunk unnecessarily.  Second, when aligning the new candidate 
> > > > > starting
> > > > >   address, the wrong bits were masked off.
> > > > >   
> > > > 
> > > > Unfortunately, this now panics a sparc64 machine on the first attempt
> > > > to use a grown resource via bus_space(9) for me:
> > > > pcib3:  at device 0.0 on pci2
> > > > pcib2: allocated I/O port range (0x1000-0x1fff) for rid 1c of pcib3
> > > > pcib2: allocated memory range (0x20-0x3ff) for rid 20 of pcib3
> > > > pcib3:   domain0
> > > > pcib3:   secondary bus 5
> > > > pcib3:   subordinate bus   5
> > > > pcib3:   I/O decode0x1000-0x1fff
> > > > pcib3:   memory decode 0x20-0x3ff
> > > > pcib3:   no prefetched decode
> > > > pcib3:   Subtractively decoded bridge.
> > > > <...>
> > > > pci3:  on pcib3
> > > > <...>
> > > > isab0:  at device 30.0 on pci3
> > > > isa0:  on isab0
> > > > <...>
> > > > rtc0:  at port 0x70-0x73 on isa0
> > > > pcib3: attempting to grow I/O port window for (0x70-0x73,0x4)
> > > > front candidate range: 0x70-0x73
> > > > pcib3: grew I/O port window to 0x70-0x1fff
> > > > panic: start address is not aligned
> > > > Alternatively, this may also be a data access trap, which also indicates
> > > > that some invalid address being used for the access.
> > > 
> > > I think this was fixed in the next commit to this file (I had gotten the
> > > mask bits on 'front' wrong).  Yes, it should be fixed by r237271:
> > > 
> > > Old version:
> > > 
> > > (gdb) p/x (0x70 & (~(1ul << 12) - 1))
> > > $1 = 0x70
> > > 
> > > Fixed version:
> > > 
> > > (gdb) p/x (0x70 & (~((1ul << 12) - 1)))
> > > $2 = 0x0
> > 
> > Well, a stock r237433 still panics with a data access trap when
> > trying to use the resource via bus_space(9). So while the math for
> > growing the window is probably right now, there still is a problem.
> 
> Hmm.  It would be interesting to know if it used to grow before (it might
> not have due to the bugs I fixed in the growing code).

Prior to r237008 growing was attempted but failed due to the bug. See
the "before:" snippet in my original email.

> 
> > > 
> > > > before:
> > > > rtc0:  at port 0x70-0x73 on isa0
> > > > pcib3: attempting to grow I/O port window for (0x70-0x73,0x4)
> > > > pcib2: allocated I/O port range (0x70-0x73) for rid 0 of rtc0
> > > > 
> > > > Shouldn't a subtractively decoded resource actually be outside of
> > > > the window of the parent PCI-PCI bridge, i.e. it seems we shouldn't
> > > > try to grow the window in that case? The below patch fixes this for
> > > > me, I'm not sure whether that actually is the right approach though.
> > > 
> > > Well, I've seen subtractive bridges with programmed windows, and the 
> > > resource 
> > > will decode properly either way.  What the current code does is allow the
> > > request to pass up the tree if growing fails.
> > 
> > By growing the window to 0x0-0x1fff in this case we are effectively
> > turning the formerly subtractively decoded resource in a positively
> > decodeded one. Maybe there's some additional bit, probably in the
> > PCI-ISA bridge, that needs to be switch for that, too? In any case,
> > growing the window in this case and by that changing the type of
> > decoding seems like a strange approach to me. Why do subtractive
> > decoders exist in the first place when the windows alternatively
> > could be grown/set up to only just do positive decoding instead?
> 
> The PCI-ISA bridge should already be decoding that range.  Note that
> subtractive decoding is slower (it has to wait for an extra cycle to
> give other devices a chance to snag a request).  I would not mind a
> tunable to control growing or not growing a window on a subtractively
> decoded bridge.  Does the firmware assign a window to this bridge
> btw?  We probably should not allocate a new window for a subtractively
> decoded bridge, but if the firmware has already assigned a window,
> growing an existing window seems less problematic.
> 

Yes, it does but switching to positive decoding nevertheless is
problematic in this case. According to the PCI 2.3 specification,
a child wanting its addresses to be decoded subtractively needs
to provide special DEVSEL# behavior. It s

svn commit: r237611 - in head/sys/dev/ath: . ath_hal ath_hal/ar5416 ath_hal/ar9002 ath_hal/ar9003

2012-06-26 Thread Adrian Chadd
Author: adrian
Date: Tue Jun 26 22:16:53 2012
New Revision: 237611
URL: http://svn.freebsd.org/changeset/base/237611

Log:
  Bring over the initial 802.11n bluetooth coexistence support code.
  
  The Linux ath9k btcoex code is based off of this code.
  
  Note this doesn't actually implement functional btcoex; there's some
  driver glue and a whole lot of verification that is required.
  
  On the other hand, I do have the AR9285+BT and AR9287+BT NICs which
  this code supports..
  
  Obtained from:Qualcomm Atheros, Linux ath9k

Added:
  head/sys/dev/ath/ath_hal/ar5416/ar5416_btcoex.c   (contents, props changed)
  head/sys/dev/ath/ath_hal/ar5416/ar5416_btcoex.h   (contents, props changed)
  head/sys/dev/ath/ath_hal/ar9002/ar9285_btcoex.c   (contents, props changed)
  head/sys/dev/ath/ath_hal/ar9003/ar9300_btcoex.h   (contents, props changed)
Modified:
  head/sys/dev/ath/ath_hal/ah.h
  head/sys/dev/ath/ath_hal/ar5416/ar5416.h
  head/sys/dev/ath/ath_hal/ar5416/ar5416_gpio.c
  head/sys/dev/ath/ath_hal/ar9002/ar9285.h
  head/sys/dev/ath/if_ath_led.c

Modified: head/sys/dev/ath/ath_hal/ah.h
==
--- head/sys/dev/ath/ath_hal/ah.h   Tue Jun 26 21:45:47 2012
(r237610)
+++ head/sys/dev/ath/ath_hal/ah.h   Tue Jun 26 22:16:53 2012
(r237611)
@@ -421,13 +421,13 @@ typedef enum {
 } HAL_INT;
 
 typedef enum {
-   HAL_GPIO_MUX_OUTPUT = 0,
-   HAL_GPIO_MUX_PCIE_ATTENTION_LED = 1,
-   HAL_GPIO_MUX_PCIE_POWER_LED = 2,
-   HAL_GPIO_MUX_TX_FRAME   = 3,
-   HAL_GPIO_MUX_RX_CLEAR_EXTERNAL  = 4,
-   HAL_GPIO_MUX_MAC_NETWORK_LED= 5,
-   HAL_GPIO_MUX_MAC_POWER_LED  = 6
+   HAL_GPIO_OUTPUT_MUX_AS_OUTPUT   = 0,
+   HAL_GPIO_OUTPUT_MUX_PCIE_ATTENTION_LED  = 1,
+   HAL_GPIO_OUTPUT_MUX_PCIE_POWER_LED  = 2,
+   HAL_GPIO_OUTPUT_MUX_MAC_NETWORK_LED = 3,
+   HAL_GPIO_OUTPUT_MUX_MAC_POWER_LED   = 4,
+   HAL_GPIO_OUTPUT_MUX_AS_WLAN_ACTIVE  = 5,
+   HAL_GPIO_OUTPUT_MUX_AS_TX_FRAME = 6
 } HAL_GPIO_MUX_TYPE;
 
 typedef enum {
@@ -777,6 +777,139 @@ struct hal_dfs_event {
 };
 typedef struct hal_dfs_event HAL_DFS_EVENT;
 
+/*
+ * BT Co-existence definitions
+ */
+typedef enum {
+   HAL_BT_MODULE_CSR_BC4   = 0,/* CSR BlueCore v4 */
+   HAL_BT_MODULE_JANUS = 1,/* Kite + Valkyrie combo */
+   HAL_BT_MODULE_HELIUS= 2,/* Kiwi + Valkyrie combo */
+   HAL_MAX_BT_MODULES
+} HAL_BT_MODULE;
+
+typedef struct {
+   HAL_BT_MODULE   bt_module;
+   u_int8_tbt_coex_config;
+   u_int8_tbt_gpio_bt_active;
+   u_int8_tbt_gpio_bt_priority;
+   u_int8_tbt_gpio_wlan_active;
+   u_int8_tbt_active_polarity;
+   HAL_BOOLbt_single_ant;
+   u_int8_tbt_dutyCycle;
+   u_int8_tbt_isolation;
+   u_int8_tbt_period;
+} HAL_BT_COEX_INFO;
+
+typedef enum {
+   HAL_BT_COEX_MODE_LEGACY = 0,/* legacy rx_clear mode */
+   HAL_BT_COEX_MODE_UNSLOTTED  = 1,/* untimed/unslotted mode */
+   HAL_BT_COEX_MODE_SLOTTED= 2,/* slotted mode */
+   HAL_BT_COEX_MODE_DISALBED   = 3,/* coexistence disabled */
+} HAL_BT_COEX_MODE;
+
+typedef enum {
+   HAL_BT_COEX_CFG_NONE,   /* No bt coex enabled */
+   HAL_BT_COEX_CFG_2WIRE_2CH,  /* 2-wire with 2 chains */
+   HAL_BT_COEX_CFG_2WIRE_CH1,  /* 2-wire with ch1 */
+   HAL_BT_COEX_CFG_2WIRE_CH0,  /* 2-wire with ch0 */
+   HAL_BT_COEX_CFG_3WIRE,  /* 3-wire */
+   HAL_BT_COEX_CFG_MCI /* MCI */
+} HAL_BT_COEX_CFG;
+
+typedef enum {
+   HAL_BT_COEX_SET_ACK_PWR = 0,/* Change ACK power setting */
+   HAL_BT_COEX_LOWER_TX_PWR,   /* Change transmit power */
+   HAL_BT_COEX_ANTENNA_DIVERSITY,  /* Enable RX diversity for Kite */
+} HAL_BT_COEX_SET_PARAMETER;
+
+#defineHAL_BT_COEX_FLAG_LOW_ACK_PWR0x0001
+#defineHAL_BT_COEX_FLAG_LOWER_TX_PWR   0x0002
+/* Check Rx Diversity is allowed */
+#defineHAL_BT_COEX_FLAG_ANT_DIV_ALLOW  0x0004
+/* Check Diversity is on or off */
+#defineHAL_BT_COEX_FLAG_ANT_DIV_ENABLE 0x0008
+
+#defineHAL_BT_COEX_ANTDIV_CONTROL1_ENABLE  0x0b
+/* main: LNA1, alt: LNA2 */
+#defineHAL_BT_COEX_ANTDIV_CONTROL2_ENABLE  0x09
+#defineHAL_BT_COEX_ANTDIV_CONTROL1_FIXED_A 0x04
+#defineHAL_BT_COEX_ANTDIV_CONTROL2_FIXED_A 0x09
+#defineHAL_BT_COEX_ANTDIV_CONTROL1_FIXED_B 0x02
+#defineHAL_BT_COEX_ANTDIV_CONTROL2_FIXED_B 0x06
+
+#defineHAL_BT_COEX_ISOLATION_FOR_NO_COEX   30
+
+#defineHAL_BT_COEX_ANT_DIV_SWITCH_COM  0x
+
+#defineHAL_BT_COEX_HELIUS_CHAINMASK0x02
+
+#defineHAL_BT_COEX_LOW_ACK_POWER   0x0
+#defineHAL_BT_COEX_HIGH_ACK_POWER  0x3f3f3f
+
+typed

svn commit: r237612 - head/share/mk

2012-06-26 Thread David E. O'Brien
Author: obrien
Date: Tue Jun 26 23:15:55 2012
New Revision: 237612
URL: http://svn.freebsd.org/changeset/base/237612

Log:
  Add -DWITH_INSTALL_AS_USER to the source build (naming matches the
  same functionality of The Ports Collection).
  This sets BINOWN, BINGRP, etc... to match current user.  This this
  allows 'install', as used in 'make install', to succeed (assuming
  user has write permissions).
  
  Submitted by: Simon J Gerraty 
  Discussed on: freebsd-arch

Modified:
  head/share/mk/bsd.own.mk

Modified: head/share/mk/bsd.own.mk
==
--- head/share/mk/bsd.own.mkTue Jun 26 22:16:53 2012(r237611)
+++ head/share/mk/bsd.own.mkTue Jun 26 23:15:55 2012(r237612)
@@ -427,6 +427,7 @@ __DEFAULT_NO_OPTIONS = \
 HESIOD \
 ICONV \
 IDEA \
+INSTALL_AS_USER \
 LIBCPLUSPLUS \
 NAND \
 OFED \
@@ -645,6 +646,17 @@ CTFCONVERT_CMD=
 CTFCONVERT_CMD=@:
 .endif 
 
+.if ${MK_INSTALL_AS_USER} != "no"
+_uid!= id -un
+.if ${_uid} != 0
+_gid!= id -gn
+.for x in BIN CONF DOC INFO KMOD LIB MAN NLS SHARE
+$xOWN= ${_uid}
+$xGRP= ${_gid}
+.endfor
+.endif
+.endif
+
 .endif # !_WITHOUT_SRCCONF
 
 .endif # !target()
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237613 - in head: contrib/less usr.bin/less

2012-06-26 Thread Xin LI
Author: delphij
Date: Tue Jun 26 23:17:33 2012
New Revision: 237613
URL: http://svn.freebsd.org/changeset/base/237613

Log:
  MFV: less v449.

Modified:
  head/contrib/less/LICENSE
  head/contrib/less/Makefile.aut
  head/contrib/less/NEWS
  head/contrib/less/README
  head/contrib/less/brac.c
  head/contrib/less/ch.c
  head/contrib/less/charset.c
  head/contrib/less/charset.h
  head/contrib/less/cmd.h
  head/contrib/less/cmdbuf.c
  head/contrib/less/command.c
  head/contrib/less/configure
  head/contrib/less/configure.ac
  head/contrib/less/cvt.c
  head/contrib/less/decode.c
  head/contrib/less/defines.ds
  head/contrib/less/defines.h.in
  head/contrib/less/defines.o2
  head/contrib/less/defines.o9
  head/contrib/less/defines.wn
  head/contrib/less/edit.c
  head/contrib/less/filename.c
  head/contrib/less/forwback.c
  head/contrib/less/help.c
  head/contrib/less/ifile.c
  head/contrib/less/input.c
  head/contrib/less/jump.c
  head/contrib/less/less.h
  head/contrib/less/less.hlp
  head/contrib/less/less.man
  head/contrib/less/less.nro
  head/contrib/less/lessecho.c
  head/contrib/less/lessecho.man
  head/contrib/less/lessecho.nro
  head/contrib/less/lesskey.c
  head/contrib/less/lesskey.h
  head/contrib/less/lesskey.man
  head/contrib/less/lesskey.nro
  head/contrib/less/lglob.h
  head/contrib/less/line.c
  head/contrib/less/linenum.c
  head/contrib/less/lsystem.c
  head/contrib/less/main.c
  head/contrib/less/mark.c
  head/contrib/less/mkhelp.c
  head/contrib/less/optfunc.c
  head/contrib/less/option.c
  head/contrib/less/option.h
  head/contrib/less/opttbl.c
  head/contrib/less/os.c
  head/contrib/less/output.c
  head/contrib/less/pattern.c
  head/contrib/less/pattern.h
  head/contrib/less/pckeys.h
  head/contrib/less/position.c
  head/contrib/less/position.h
  head/contrib/less/prompt.c
  head/contrib/less/screen.c
  head/contrib/less/scrsize.c
  head/contrib/less/search.c
  head/contrib/less/signal.c
  head/contrib/less/tags.c
  head/contrib/less/ttyin.c
  head/contrib/less/version.c
  head/usr.bin/less/defines.h
Directory Properties:
  head/contrib/less/   (props changed)

Modified: head/contrib/less/LICENSE
==
--- head/contrib/less/LICENSE   Tue Jun 26 23:15:55 2012(r237612)
+++ head/contrib/less/LICENSE   Tue Jun 26 23:17:33 2012(r237613)
@@ -2,7 +2,7 @@
   
 
 Less
-Copyright (C) 1984-2011  Mark Nudelman
+Copyright (C) 1984-2012  Mark Nudelman
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions

Modified: head/contrib/less/Makefile.aut
==
--- head/contrib/less/Makefile.aut  Tue Jun 26 23:15:55 2012
(r237612)
+++ head/contrib/less/Makefile.aut  Tue Jun 26 23:17:33 2012
(r237613)
@@ -1,6 +1,6 @@
 # Makefile for authoring less.
 
-EMAIL = ma...@greenwoodsoftware.com
+EMAIL = bug-l...@gnu.org
 HOMEPAGE = http://www.greenwoodsoftware.com/less
 SHELL = /bin/sh
 RCS = rcs
@@ -112,8 +112,7 @@ dist: ${DISTFILES}
echo "Preparing $$REL"; \
rm -rf $$REL; mkdir $$REL; \
for file in ${DISTFILES}; do \
- cp -p $$file $$REL; \
- chmod -w $$REL/$$file; \
+ ./add_copyright $$file $$REL; \
done; \
cd $$REL; chmod +w ${DISTFILES_W}; cd ..; \
echo "Creating release/$$REL/$$REL.tar.gz"; \

Modified: head/contrib/less/NEWS
==
--- head/contrib/less/NEWS  Tue Jun 26 23:15:55 2012(r237612)
+++ head/contrib/less/NEWS  Tue Jun 26 23:17:33 2012(r237613)
@@ -7,8 +7,34 @@
   http://www.greenwoodsoftware.com/less
   You can also download the latest version of less from there.
 
-  To report bugs, suggestions or comments, send email to 
-  bug-l...@gnu.org or ma...@greenwoodsoftware.com.
+  To report bugs, suggestions or comments, send email to bug-l...@gnu.org.
+
+==
+
+   Major changes between "less" versions 444 and 449
+
+* Add ESC-F command to keep reading data until a pattern is found.
+
+* Use exit code of LESSOPEN script if LESSOPEN starts with "||".
+
+* When up/down arrow is used on the command line immediately after
+  typing text, the next command starting with that text is found.
+
+* Add support for GNU regex.
+
+* Add configure option --with-regex=none and fix compile errors
+  when compiling with no regex library.
+
+* Fix bugs handling SGR sequences in Win32.
+
+* Fix possible crashes caused by malformed LESSOPEN or 
+  LESSCLOSE variables.
+
+* Fix bug highlighting text which is discontiguous in the file 
+  due to backspace processing.
+
+* Fix bug in displaying status column when scrolling backwards 
+  with -J and -S in effect.
 
 

svn commit: r237618 - head/usr.bin/killall

2012-06-26 Thread Xin LI
Author: delphij
Date: Wed Jun 27 00:50:25 2012
New Revision: 237618
URL: http://svn.freebsd.org/changeset/base/237618

Log:
  Add a -I flag which requests confirmation before action, like what is done
  in pkill(1).
  
  MFC after:2 weeks

Modified:
  head/usr.bin/killall/killall.1
  head/usr.bin/killall/killall.c

Modified: head/usr.bin/killall/killall.1
==
--- head/usr.bin/killall/killall.1  Wed Jun 27 00:37:22 2012
(r237617)
+++ head/usr.bin/killall/killall.1  Wed Jun 27 00:50:25 2012
(r237618)
@@ -24,7 +24,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd December 25, 2009
+.Dd June 27, 2012
 .Dt KILLALL 1
 .Os
 .Sh NAME
@@ -34,6 +34,7 @@
 .Nm
 .Op Fl delmsvz
 .Op Fl help
+.Op Fl I
 .Op Fl j Ar jail
 .Op Fl u Ar user
 .Op Fl t Ar tty
@@ -71,6 +72,9 @@ processes specified with the
 option.
 .It Fl help
 Give a help on the command usage and exit.
+.It Fl I
+Request confirmation before attempting to signal each
+process.
 .It Fl l
 List the names of the available signals and exit, like in
 .Xr kill 1 .

Modified: head/usr.bin/killall/killall.c
==
--- head/usr.bin/killall/killall.c  Wed Jun 27 00:37:22 2012
(r237617)
+++ head/usr.bin/killall/killall.c  Wed Jun 27 00:50:25 2012
(r237618)
@@ -53,7 +53,7 @@ static void __dead2
 usage(void)
 {
 
-   fprintf(stderr, "usage: killall [-delmsvz] [-help] [-j jail]\n");
+   fprintf(stderr, "usage: killall [-delmsvz] [-help] [-I] [-j jail]\n");
fprintf(stderr,
"   [-u user] [-t tty] [-c cmd] [-SIGNAL] [cmd]...\n");
fprintf(stderr, "At least one option or argument to specify processes 
must be given.\n");
@@ -95,8 +95,9 @@ main(int ac, char **av)
struct passwd   *pw;
regex_t rgx;
regmatch_t  pmatch;
-   int i, j;
+   int i, j, ch;
charbuf[256];
+   charfirst;
char*user = NULL;
char*tty = NULL;
char*cmd = NULL;
@@ -104,6 +105,7 @@ main(int ac, char **av)
int sflag = 0;
int dflag = 0;
int eflag = 0;
+   int Iflag = 0;
int jflag = 0;
int mflag = 0;
int zflag = 0;
@@ -141,6 +143,9 @@ main(int ac, char **av)
if (**av == '-') {
++*av;
switch (**av) {
+   case 'I':
+   Iflag = 1;
+   break;
case 'j':
++*av;
if (**av == '\0') {
@@ -382,6 +387,16 @@ main(int ac, char **av)
if (matched)
break;
}
+   if (matched != 0 && Iflag) {
+   printf("Send signal %d to %s (pid %d uid %d)? ",
+   sig, thiscmd, thispid, thisuid);
+   fflush(stdout);
+   first = ch = getchar();
+   while (ch != '\n' && ch != EOF)
+   ch = getchar();
+   if (first != 'y' && first != 'Y')
+   matched = 0;
+   }
if (matched == 0)
continue;
if (dflag)
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237619 - head/share/man/man9

2012-06-26 Thread Julian Elischer
Author: julian
Date: Wed Jun 27 01:13:37 2012
New Revision: 237619
URL: http://svn.freebsd.org/changeset/base/237619

Log:
  Try clean up some of my original text and neaten a table.
  
  MFC after:1 week

Modified:
  head/share/man/man9/locking.9

Modified: head/share/man/man9/locking.9
==
--- head/share/man/man9/locking.9   Wed Jun 27 00:50:25 2012
(r237618)
+++ head/share/man/man9/locking.9   Wed Jun 27 01:13:37 2012
(r237619)
@@ -37,11 +37,19 @@ kernel is written to run across multiple
 several different synchronization primitives to allow the developers
 to safely access and manipulate the many data types required.
 .Ss Mutexes
-Mutexes (also called "sleep mutexes") are the most commonly used
+Mutexes (also erroneously called "sleep mutexes") are the most commonly used
 synchronization primitive in the kernel.
-Thread acquires (locks) a mutex before accessing data shared with other
+A thread acquires (locks) a mutex before accessing data shared with other
 threads (including interrupt threads), and releases (unlocks) it afterwards.
-If the mutex cannot be acquired, the thread requesting it will sleep.
+If the mutex cannot be acquired, the thread requesting it will wait.
+Mutexes are by default adaptive, meaning that
+if the owner of a contended mutex is currently running on another CPU,
+then a thread attempting to acquire the mutex will briefly spin
+in the hope that the owner is only briefly holding it,
+and might release it shortly.
+If the owner does not do so, the waiting thread proceeds to yield the 
processor,
+allowing other threads to run.
+If the owner is not currently actually running then the spin step is skipped.
 Mutexes fully support priority propagation.
 .Pp
 See
@@ -49,9 +57,10 @@ See
 for details.
 .Ss Spin mutexes
 Spin mutexes are variation of basic mutexes; the main difference between
-the two is that spin mutexes never sleep - instead, they spin, waiting
-for the thread holding the lock, which runs on another CPU, to release it.
-Differently from ordinary mutex, spin mutexes disable interrupts when acquired.
+the two is that spin mutexes never yield the processor - instead, they spin,
+waiting for the thread holding the lock,
+(which must be running on another CPU), to release it.
+Spin mutexes disable interrupts while the held so as to not get pre-empted.
 Since disabling interrupts is expensive, they are also generally slower.
 Spin mutexes should be used only when necessary, e.g. to protect data shared
 with interrupt filter code (see
@@ -122,7 +131,7 @@ and read-mostly locks.
 They don't support priority propagation.
 They should be considered to be closely related to
 .Xr sleep 9 .
-In fact it could in some cases be
+They could in some cases be
 considered a conditional sleep.
 .Pp
 See
@@ -146,8 +155,8 @@ A thread must hold the mutex before call
 .Fn cv_wait* ,
 functions.
 When a thread waits on a condition, the mutex
-is atomically released before the thread is blocked, then reacquired
-before the function call returns.
+is atomically released before the thread thread yields the processor,
+then reacquired before the function call returns.
 .Pp
 See
 .Xr condvar 9
@@ -255,14 +264,14 @@ Many of these rules are checked using th
 .Xr witness 4
 code.
 .Ss Bounded vs. unbounded sleep
-The following primitives perform bounded sleep: mutexes, pool mutexes,
-reader/writer locks and read-mostly locks.
+The following primitives perform bounded sleep:
+ mutexes, pool mutexes, reader/writer locks and read-mostly locks.
 .Pp
-The following primitives block (perform unbounded sleep): shared/exclusive 
locks,
-counting semaphores, condition variables, sleep/wakeup and lockmanager locks.
+The following primitives may perform an unbounded sleep:
+shared/exclusive locks, counting semaphores, condition variables, sleep/wakeup 
and lockmanager locks.
 .Pp
-It is an error to do any operation that could result in any kind of sleep while
-holding spin mutex.
+It is an error to do any operation that could result in yielding the processor
+while holding a spin mutex.
 .Pp
 As a general rule, it is an error to do any operation that could result
 in unbounded sleep while holding any primitive from the 'bounded sleep' group.
@@ -284,21 +293,22 @@ Because the lock gets dropped during sle
 the assumptions that were made before, all the way up the call graph to the
 place where the lock was acquired.
 .Pp
-It is an error to do any operation that could result in any kind of sleep when
-running inside an interrupt filter.
+It is an error to do any operation that could result in yielding of
+the processor when running inside an interrupt filter.
 .Pp
 It is an error to do any operation that could result in unbounded sleep when
 running inside an interrupt thread.
 .Ss Interaction table
 The following table shows what you can and can not do while holding
 one of the synchronization primitives discussed

svn commit: r237620 - head/sbin/geom/class/raid

2012-06-26 Thread Warren Block
Author: wblock (doc committer)
Date: Wed Jun 27 01:44:48 2012
New Revision: 237620
URL: http://svn.freebsd.org/changeset/base/237620

Log:
  Use possessive "its", no apostrophe.
  
  MFC after:1 day

Modified:
  head/sbin/geom/class/raid/graid.8

Modified: head/sbin/geom/class/raid/graid.8
==
--- head/sbin/geom/class/raid/graid.8   Wed Jun 27 01:13:37 2012
(r237619)
+++ head/sbin/geom/class/raid/graid.8   Wed Jun 27 01:44:48 2012
(r237620)
@@ -85,7 +85,7 @@ utility is used to manage software RAID 
 GEOM RAID class.
 GEOM RAID class uses on-disk metadata to provide access to software-RAID
 volumes defined by different RAID BIOSes.
-Depending on RAID BIOS type and it's metadata format, different subsets of
+Depending on RAID BIOS type and its metadata format, different subsets of
 configurations and features are supported.
 To allow booting from RAID volume, the metadata format should match the
 RAID BIOS type and its capabilities.
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237621 - head/sys/dev/ath/ath_hal/ar5416

2012-06-26 Thread Adrian Chadd
Author: adrian
Date: Wed Jun 27 03:00:29 2012
New Revision: 237621
URL: http://svn.freebsd.org/changeset/base/237621

Log:
  Remove duplicate entries.

Modified:
  head/sys/dev/ath/ath_hal/ar5416/ar5416_btcoex.h

Modified: head/sys/dev/ath/ath_hal/ar5416/ar5416_btcoex.h
==
--- head/sys/dev/ath/ath_hal/ar5416/ar5416_btcoex.h Wed Jun 27 01:44:48 
2012(r237620)
+++ head/sys/dev/ath/ath_hal/ar5416/ar5416_btcoex.h Wed Jun 27 03:00:29 
2012(r237621)
@@ -28,37 +28,4 @@
 #define AR5416_STOMP_ALL_FORCE_WLAN_WGHT   0x   // Stomp BT even when 
WLAN is idle
 #define AR5416_STOMP_LOW_FORCE_WLAN_WGHT   0x   // Stomp BT even when 
WLAN is idle
 
-#define AR9300_BT_WGHT 0x
-#define AR9300_STOMP_ALL_WLAN_WGHT00xfff0
-#define AR9300_STOMP_ALL_WLAN_WGHT10xfff0
-#define AR9300_STOMP_LOW_WLAN_WGHT00x8880
-#define AR9300_STOMP_LOW_WLAN_WGHT10x8880
-#define AR9300_STOMP_NONE_WLAN_WGHT0   0x
-#define AR9300_STOMP_NONE_WLAN_WGHT1   0x
-#define AR9300_STOMP_ALL_FORCE_WLAN_WGHT0  0x   // Stomp BT even when 
WLAN is idle
-#define AR9300_STOMP_ALL_FORCE_WLAN_WGHT1  0x
-#define AR9300_STOMP_LOW_FORCE_WLAN_WGHT0  0x   // Stomp BT even when 
WLAN is idle
-#define AR9300_STOMP_LOW_FORCE_WLAN_WGHT1  0x
-
-#define JUPITER_STOMP_ALL_WLAN_WGHT0   0x7d00
-#define JUPITER_STOMP_ALL_WLAN_WGHT1   0x7d7d7d00
-#define JUPITER_STOMP_ALL_WLAN_WGHT2   0x7d7d7d00
-#define JUPITER_STOMP_ALL_WLAN_WGHT3   0x7d7d7d7d
-#define JUPITER_STOMP_LOW_WLAN_WGHT0   0x7d00
-#define JUPITER_STOMP_LOW_WLAN_WGHT1   0x7d3b3b00
-#define JUPITER_STOMP_LOW_WLAN_WGHT2   0x3b3b3b00
-#define JUPITER_STOMP_LOW_WLAN_WGHT3   0x3b3b3b3b
-#define JUPITER_STOMP_NONE_WLAN_WGHT0  0x7d00
-#define JUPITER_STOMP_NONE_WLAN_WGHT1  0x7d00
-#define JUPITER_STOMP_NONE_WLAN_WGHT2  0x
-#define JUPITER_STOMP_NONE_WLAN_WGHT3  0x
-#define JUPITER_STOMP_ALL_FORCE_WLAN_WGHT0 0x7d7d
-#define JUPITER_STOMP_ALL_FORCE_WLAN_WGHT1 0x7d7d7d00
-#define JUPITER_STOMP_ALL_FORCE_WLAN_WGHT2 0x7d7d7d7d
-#define JUPITER_STOMP_ALL_FORCE_WLAN_WGHT3 0x7d7d7d7d
-#define JUPITER_STOMP_LOW_FORCE_WLAN_WGHT0 0x3b3b
-#define JUPITER_STOMP_LOW_FORCE_WLAN_WGHT1 0x3b3b3b00
-#define JUPITER_STOMP_LOW_FORCE_WLAN_WGHT2 0x3b3b3b3b
-#define JUPITER_STOMP_LOW_FORCE_WLAN_WGHT3 0x3b3b3b3b
-
 #endif /* __ATH_AR5416_BTCOEX_H__ */
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237622 - head/sys/dev/ath/ath_hal

2012-06-26 Thread Adrian Chadd
Author: adrian
Date: Wed Jun 27 03:24:27 2012
New Revision: 237622
URL: http://svn.freebsd.org/changeset/base/237622

Log:
  Bring over some new typedefs as part of the AR9300 HAL import.

Modified:
  head/sys/dev/ath/ath_hal/ah.h

Modified: head/sys/dev/ath/ath_hal/ah.h
==
--- head/sys/dev/ath/ath_hal/ah.h   Wed Jun 27 03:00:29 2012
(r237621)
+++ head/sys/dev/ath/ath_hal/ah.h   Wed Jun 27 03:24:27 2012
(r237622)
@@ -420,6 +420,30 @@ typedef enum {
| HAL_INT_GPIO,
 } HAL_INT;
 
+/*
+ * MSI vector assignments
+ */
+typedef enum {
+   HAL_MSIVEC_MISC = 0,
+   HAL_MSIVEC_TX   = 1,
+   HAL_MSIVEC_RXLP = 2,
+   HAL_MSIVEC_RXHP = 3,
+} HAL_MSIVEC;
+
+typedef enum {
+   HAL_INT_LINE = 0,
+   HAL_INT_MSI  = 1,
+} HAL_INT_TYPE;
+
+/* For interrupt mitigation registers */
+typedef enum {
+   HAL_INT_RX_FIRSTPKT=0,
+   HAL_INT_RX_LASTPKT,
+   HAL_INT_TX_FIRSTPKT,
+   HAL_INT_TX_LASTPKT,
+   HAL_INT_THRESHOLD
+} HAL_INT_MITIGATION;
+
 typedef enum {
HAL_GPIO_OUTPUT_MUX_AS_OUTPUT   = 0,
HAL_GPIO_OUTPUT_MUX_PCIE_ATTENTION_LED  = 1,
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237623 - in head/sys: amd64/amd64 i386/i386 kern sparc64/sparc64 vm

2012-06-26 Thread Alan Cox
Author: alc
Date: Wed Jun 27 03:45:25 2012
New Revision: 237623
URL: http://svn.freebsd.org/changeset/base/237623

Log:
  Add new pmap layer locks to the predefined lock order.  Change the names
  of a few existing VM locks to follow a consistent naming scheme.

Modified:
  head/sys/amd64/amd64/pmap.c
  head/sys/i386/i386/pmap.c
  head/sys/kern/subr_witness.c
  head/sys/sparc64/sparc64/pmap.c
  head/sys/vm/vm_map.c
  head/sys/vm/vm_page.c

Modified: head/sys/amd64/amd64/pmap.c
==
--- head/sys/amd64/amd64/pmap.c Wed Jun 27 03:24:27 2012(r237622)
+++ head/sys/amd64/amd64/pmap.c Wed Jun 27 03:45:25 2012(r237623)
@@ -642,7 +642,7 @@ pmap_bootstrap(vm_paddr_t *firstaddr)
/*
 * Initialize the global pv list lock.
 */
-   rw_init(&pvh_global_lock, "pvh global");
+   rw_init(&pvh_global_lock, "pmap pv global");
 
/*
 * Reserve some special page table entries/VA space for temporary
@@ -810,13 +810,13 @@ pmap_init(void)
/*
 * Initialize the pv chunk list mutex.
 */
-   mtx_init(&pv_chunks_mutex, "pv chunk list", NULL, MTX_DEF);
+   mtx_init(&pv_chunks_mutex, "pmap pv chunk list", NULL, MTX_DEF);
 
/*
 * Initialize the pool of pv list locks.
 */
for (i = 0; i < NPV_LIST_LOCKS; i++)
-   rw_init(&pv_list_locks[i], "pv list");
+   rw_init(&pv_list_locks[i], "pmap pv list");
 
/*
 * Calculate the size of the pv head table for superpages.

Modified: head/sys/i386/i386/pmap.c
==
--- head/sys/vm/vm_map.cWed Jun 27 03:24:27 2012(r237622)
+++ head/sys/vm/vm_map.cWed Jun 27 03:45:25 2012(r237623)
@@ -241,8 +241,8 @@ vm_map_zinit(void *mem, int size, int fl
map = (vm_map_t)mem;
map->nentries = 0;
map->size = 0;
-   mtx_init(&map->system_mtx, "system map", NULL, MTX_DEF | MTX_DUPOK);
-   sx_init(&map->lock, "user map");
+   mtx_init(&map->system_mtx, "vm map (system)", NULL, MTX_DEF | 
MTX_DUPOK);
+   sx_init(&map->lock, "vm map (user)");
return (0);
 }
 

Modified: head/sys/vm/vm_page.c
==
--- head/sy

svn commit: r237624 - in head: cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize cddl/contrib/opensolaris/lib/libdtrace/common sys/cddl/contrib/opensolaris/uts/common/dtrace sys/cddl/c...

2012-06-26 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Jun 27 04:39:30 2012
New Revision: 237624
URL: http://svn.freebsd.org/changeset/base/237624

Log:
  Bring llquantize support into Dtrace.
  
  Bryan Cantrill implemented the equivalent of semi-log graph
  paper for Dtrace so llquantize will use one logarithmic and
  one linear scale.
  
  Special thanks to Mark Peek for providing fix to an
  assertion and to Fabian Keill for testing the port.
  
  Illumos Revision: 13355:15b74a2a9a9d
  
  Reference:
  https://www.illumos/issues/905
  
  Obtained from:Illumos
  Tested by:Fabian Keill, mp
  MFC after:4 days

Added:
  head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTOREVEN.nodivide.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTOREVEN.notfactor.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTORMATCH.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTORNSTEPS.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTORSMALL.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTORTYPE.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_FACTORVAL.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_HIGHMATCH.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_HIGHTYPE.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_HIGHVAL.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_LOWMATCH.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_LOWTYPE.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_LOWVAL.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_MAGRANGE.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_MAGTOOBIG.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_NSTEPMATCH.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_NSTEPTYPE.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/err.D_LLQUANT_NSTEPVAL.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.bases.d 
  (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.bases.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.basic.d 
  (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.basic.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.negorder.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.negorder.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.negvalue.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.negvalue.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.normal.d
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.normal.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.range.d 
  (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.range.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.steps.d 
  (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.steps.d.out
   (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.trunc.d 
  (contents, props changed)
  
head/cddl/contrib/opensolaris/cmd/dtrace/test/tst/common/llquantize/tst.trunc.d.out
   (contents, props changed)
Modified:
  head/cddl/contrib/opensolaris/lib/libdtrace/common/dt_aggregate.c
  head/cddl/contrib/opensolaris/lib/libdtrace/common/dt_cc.c
  head/cddl/contrib/opensolaris/lib/libdtrace/common

svn commit: r237625 - in head/usr.sbin/crunch: crunchgen crunchide

2012-06-26 Thread David E. O'Brien
Author: obrien
Date: Wed Jun 27 04:39:30 2012
New Revision: 237625
URL: http://svn.freebsd.org/changeset/base/237625

Log:
  Some amount of style(9)
-- function definitions, header ordering, and $FreeBSD$.

Modified:
  head/usr.sbin/crunch/crunchgen/crunched_main.c
  head/usr.sbin/crunch/crunchgen/crunchgen.c
  head/usr.sbin/crunch/crunchide/crunchide.c

Modified: head/usr.sbin/crunch/crunchgen/crunched_main.c
==
--- head/usr.sbin/crunch/crunchgen/crunched_main.c  Wed Jun 27 04:39:30 
2012(r237624)
+++ head/usr.sbin/crunch/crunchgen/crunched_main.c  Wed Jun 27 04:39:30 
2012(r237625)
@@ -22,8 +22,6 @@
  * Author: James da Silva, Systems Design and Analysis Group
  *Computer Science Department
  *University of Maryland at College Park
- *
- * $FreeBSD$
  */
 /*
  * crunched_main.c - main program for crunched binaries, it branches to a
@@ -33,6 +31,10 @@
  * or calls one of them based on argv[1].   This allows the testing of
  * the crunched binary without creating all the links.
  */
+
+#include 
+__FBSDID("$FreeBSD$");
+
 #include 
 #include 
 #include 
@@ -45,7 +47,8 @@ struct stub {
 extern char *__progname;
 extern struct stub entry_points[];
 
-int main(int argc, char **argv, char **envp)
+int
+main(int argc, char **argv, char **envp)
 {
 char *slash, *basename;
 struct stub *ep;
@@ -68,7 +71,8 @@ int main(int argc, char **argv, char **e
 }
 
 
-int crunched_here(char *path)
+int
+crunched_here(char *path)
 {
 char *slash, *basename;
 struct stub *ep;
@@ -83,7 +87,8 @@ int crunched_here(char *path)
 }
 
 
-int crunched_main(int argc, char **argv, char **envp)
+int
+crunched_main(int argc, char **argv, char **envp)
 {
 char *slash;
 struct stub *ep;
@@ -99,7 +104,8 @@ int crunched_main(int argc, char **argv,
 }
 
 
-int crunched_usage()
+int
+crunched_usage()
 {
 int columns, len;
 struct stub *ep;
@@ -122,4 +128,3 @@ int crunched_usage()
 }
 
 /* end of crunched_main.c */
-

Modified: head/usr.sbin/crunch/crunchgen/crunchgen.c
==
--- head/usr.sbin/crunch/crunchgen/crunchgen.c  Wed Jun 27 04:39:30 2012
(r237624)
+++ head/usr.sbin/crunch/crunchgen/crunchgen.c  Wed Jun 27 04:39:30 2012
(r237625)
@@ -22,8 +22,6 @@
  * Author: James da Silva, Systems Design and Analysis Group
  *Computer Science Department
  *University of Maryland at College Park
- *
- * $FreeBSD$
  */
 /*
  * 
@@ -32,9 +30,12 @@
  * Generates a Makefile and main C file for a crunched executable,
  * from specs given in a .conf file.
  */
-#include 
-#include 
+
+#include 
+__FBSDID("$FreeBSD$");
+
 #include 
+#include 
 
 #include 
 #include 
@@ -119,7 +120,8 @@ void parse_conf_file(void);
 void gen_outputs(void);
 
 
-int main(int argc, char **argv)
+int
+main(int argc, char **argv)
 {
char *p;
int optc;
@@ -223,7 +225,8 @@ int main(int argc, char **argv)
 }
 
 
-void usage(void)
+void
+usage(void)
 {
fprintf(stderr, "%s%s\n\t%s%s\n", "usage: crunchgen [-foq] ",
"[-h ] [-m ]",
@@ -255,7 +258,8 @@ prog_t *find_prog(char *str);
 void add_prog(char *progname);
 
 
-void parse_conf_file(void)
+void
+parse_conf_file(void)
 {
if (!is_nonempty_file(infilename))
errx(1, "fatal: input file \"%s\" not found", infilename);
@@ -268,7 +272,8 @@ void parse_conf_file(void)
 }
 
 
-void parse_one_file(char *filename)
+void
+parse_one_file(char *filename)
 {
char *fieldv[MAXFIELDS];
int fieldc;
@@ -334,7 +339,8 @@ void parse_one_file(char *filename)
 }
 
 
-void parse_line(char *line, int *fc, char **fv, int nf)
+void
+parse_line(char *line, int *fc, char **fv, int nf)
 {
char *p;
 
@@ -365,7 +371,8 @@ void parse_line(char *line, int *fc, cha
 }
 
 
-void add_srcdirs(int argc, char **argv)
+void
+add_srcdirs(int argc, char **argv)
 {
int i;
 
@@ -381,7 +388,8 @@ void add_srcdirs(int argc, char **argv)
 }
 
 
-void add_progs(int argc, char **argv)
+void
+add_progs(int argc, char **argv)
 {
int i;
 
@@ -390,7 +398,8 @@ void add_progs(int argc, char **argv)
 }
 
 
-void add_prog(char *progname)
+void
+add_prog(char *progname)
 {
prog_t *p1, *p2;
 
@@ -431,7 +440,8 @@ void add_prog(char *progname)
 }
 
 
-void add_link(int argc, char **argv)
+void
+add_link(int argc, char **argv)
 {
int i;
prog_t *p = find_prog(argv[1]);
@@ -452,7 +462,8 @@ void add_link(int argc, char **argv)
 }
 
 
-void add_libs(int argc, char **argv)
+void
+add_libs(int argc, char **argv)
 {
int i;
 
@@ -466,7 +477,8 @@ void add_libs(int argc, char **argv)
 }
 
 
-void add_libs_so(int argc, char **argv)
+void
+add_libs_so(int argc, char **argv)
 {
int i;

svn commit: r237626 - head/sys/dev/ath/ath_hal/ar5416

2012-06-26 Thread Adrian Chadd
Author: adrian
Date: Wed Jun 27 05:23:33 2012
New Revision: 237626
URL: http://svn.freebsd.org/changeset/base/237626

Log:
  Fix a subtle corner case surrounding the handling of OFDM restart along
  with AMPDU aggregate delimiters.
  
  If there's an OFDM restart during an aggregate, the hardware ACKs
  the previous frame, but communicates the RXed frame to the hardware
  as having had CRC delimiter error + OFDM_RESTART phy error.
  The frame however didn't have a CRC error and since the hardware ACKed
  the aggregate to the sender, it thinks the frame was received.
  
  Since I have no idea how often this occurs in the real world, add a
  debug statement so trigger whenever this occurs.  I'd appreciate an
  email if someone finds this particular situation is triggered.

Modified:
  head/sys/dev/ath/ath_hal/ar5416/ar5416_recv.c

Modified: head/sys/dev/ath/ath_hal/ar5416/ar5416_recv.c
==
--- head/sys/dev/ath/ath_hal/ar5416/ar5416_recv.c   Wed Jun 27 04:39:30 
2012(r237625)
+++ head/sys/dev/ath/ath_hal/ar5416/ar5416_recv.c   Wed Jun 27 05:23:33 
2012(r237626)
@@ -240,11 +240,25 @@ ar5416ProcRxDesc(struct ath_hal *ah, str
if (ads->ds_rxstatus8 & AR_PHYErr) {
u_int phyerr;
 
-   rs->rs_status |= HAL_RXERR_PHY;
+   /*
+* Packets with OFDM_RESTART on post delimiter are CRC 
OK and
+* usable and MAC ACKs them.
+* To avoid packet from being lost, we remove the PHY 
Err flag
+* so that driver layer does not drop them.
+*/
phyerr = MS(ads->ds_rxstatus8, AR_PHYErrCode);
-   rs->rs_phyerr = phyerr;
-   }
 
+   if ((phyerr == HAL_PHYERR_OFDM_RESTART) &&
+   (ads->ds_rxstatus8 & AR_PostDelimCRCErr)) {
+   ath_hal_printf(ah,
+   "%s: OFDM_RESTART on post-delim CRC 
error\n",
+   __func__);
+   rs->rs_phyerr = 0;
+   } else {
+   rs->rs_status |= HAL_RXERR_PHY;
+   rs->rs_phyerr = phyerr;
+   }
+   }
if (ads->ds_rxstatus8 & AR_CRCErr)
rs->rs_status |= HAL_RXERR_CRC;
else if (ads->ds_rxstatus8 & AR_DecryptCRCErr)
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237628 - head/usr.bin/sort

2012-06-26 Thread Gabor Kovesdan
Author: gabor
Date: Wed Jun 27 05:50:15 2012
New Revision: 237628
URL: http://svn.freebsd.org/changeset/base/237628

Log:
  - Disable threaded sort by default
  - Fix typo in the NLS support

Modified:
  head/usr.bin/sort/Makefile

Modified: head/usr.bin/sort/Makefile
==
--- head/usr.bin/sort/Makefile  Wed Jun 27 05:38:39 2012(r237627)
+++ head/usr.bin/sort/Makefile  Wed Jun 27 05:50:15 2012(r237628)
@@ -21,7 +21,7 @@ sort.1: sort.1.in
 
 CLEANFILES+= sort.1
 
-.if !defined(WITHOUT_THREADS)
+.if defined(WITH_THREADS)
 CFLAGS+= -DSORT_THREADS
 LDFLAGS+= -lpthread -lmd
 MAN_SUB+= -e 's|%%THREADS%%||g'
@@ -39,7 +39,7 @@ NLSSRCDIR_${lang}= ${.CURDIR}/nls
 .endfor
 .else
 CFLAGS+= -DWITHOUT_NLS
-MAN_SUB+= -e 's|%%THREADS%%|\.\\"|g'
+MAN_SUB+= -e 's|%%NLS%%|\.\\"|g'
 .endif
 
 .include 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237629 - in head: gnu/usr.bin/sort share/mk tools/build/options usr.bin/sort

2012-06-26 Thread Gabor Kovesdan
Author: gabor
Date: Wed Jun 27 05:59:01 2012
New Revision: 237629
URL: http://svn.freebsd.org/changeset/base/237629

Log:
  - Switch to BSD sort as default sort.  GNU sort will still be installed as
"gnusort".  Most of the BSD sort development work was done by
Oleg Moskalenko .
  - GNU grep can be set to default by setting WITH_GNU_GREP.  It will cause
BSD sort to be installed as "bsdsort".
  
  Portbuild tested by:linimon

Added:
  head/tools/build/options/WITH_GNU_SORT   (contents, props changed)
Deleted:
  head/tools/build/options/WITH_BSD_SORT
Modified:
  head/gnu/usr.bin/sort/Makefile
  head/share/mk/bsd.own.mk
  head/usr.bin/sort/Makefile

Modified: head/gnu/usr.bin/sort/Makefile
==
--- head/gnu/usr.bin/sort/Makefile  Wed Jun 27 05:50:15 2012
(r237628)
+++ head/gnu/usr.bin/sort/Makefile  Wed Jun 27 05:59:01 2012
(r237629)
@@ -5,7 +5,7 @@ SORTDIR= ${.CURDIR}/../../../contrib/gnu
 
 .include 
 
-.if ${MK_BSD_SORT} != "yes"
+.if ${MK_GNU_SORT} == "yes"
 PROG=  sort
 .else
 PROG=  gnusort

Modified: head/share/mk/bsd.own.mk
==
--- head/share/mk/bsd.own.mkWed Jun 27 05:50:15 2012(r237628)
+++ head/share/mk/bsd.own.mkWed Jun 27 05:59:01 2012(r237629)
@@ -415,7 +415,6 @@ __DEFAULT_YES_OPTIONS = \
 
 __DEFAULT_NO_OPTIONS = \
 BSD_GREP \
-BSD_SORT \
 BIND_IDN \
 BIND_LARGE_FILE \
 BIND_LIBS \
@@ -424,6 +423,7 @@ __DEFAULT_NO_OPTIONS = \
 CLANG_EXTRAS \
 CLANG_IS_CC \
 CTF \
+GNU_SORT \
 HESIOD \
 ICONV \
 IDEA \

Added: head/tools/build/options/WITH_GNU_SORT
==
--- /dev/null   00:00:00 1970   (empty, because file is newly added)
+++ head/tools/build/options/WITH_GNU_SORT  Wed Jun 27 05:59:01 2012
(r237629)
@@ -0,0 +1,2 @@
+.\" $FreeBSD$
+Install GNU-licensed sort as 'sort' instead of BSD sort.

Modified: head/usr.bin/sort/Makefile
==
--- head/usr.bin/sort/Makefile  Wed Jun 27 05:50:15 2012(r237628)
+++ head/usr.bin/sort/Makefile  Wed Jun 27 05:59:01 2012(r237629)
@@ -2,7 +2,7 @@
 
 .include 
 
-.if ${MK_BSD_SORT} == "yes"
+.if ${MK_GNU_SORT} != "yes"
 PROG=  sort
 .else
 PROG=  bsdsort
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237630 - head/share/man/man5

2012-06-26 Thread Gabor Kovesdan
Author: gabor
Date: Wed Jun 27 06:00:58 2012
New Revision: 237630
URL: http://svn.freebsd.org/changeset/base/237630

Log:
  - Regen after BSD sort change

Modified:
  head/share/man/man5/src.conf.5

Modified: head/share/man/man5/src.conf.5
==
--- head/share/man/man5/src.conf.5  Wed Jun 27 05:59:01 2012
(r237629)
+++ head/share/man/man5/src.conf.5  Wed Jun 27 06:00:58 2012
(r237630)
@@ -1,7 +1,7 @@
 .\" DO NOT EDIT-- this file is automatically generated.
 .\" from FreeBSD: head/tools/build/options/makeman 236279 2012-05-30 02:37:20Z 
gjb
 .\" $FreeBSD$
-.Dd May 29, 2012
+.Dd June 27, 2012
 .Dt SRC.CONF 5
 .Os
 .Sh NAME
@@ -227,9 +227,6 @@ Set to not build the BSD licensed versio
 .It Va WITH_BSD_GREP
 .\" from FreeBSD: head/tools/build/options/WITH_BSD_GREP 73 2011-05-25 
01:04:12Z obrien
 Install BSD-licensed grep as '[ef]grep' instead of GNU grep.
-.It Va WITH_BSD_SORT
-.\" from FreeBSD: head/tools/build/options/WITH_BSD_SORT 235268 2012-05-11 
12:47:21Z gabor
-Install BSD-licensed sort as 'sort' instead of GNU sort.
 .It Va WITHOUT_BSNMP
 .\" from FreeBSD: head/tools/build/options/WITHOUT_BSNMP 183306 2008-09-23 
16:15:42Z sam
 Set to not build or install
@@ -440,6 +437,9 @@ When set, it also enforces the following
 .It
 .Va WITHOUT_GNU_SUPPORT
 .El
+.It Va WITH_GNU_SORT
+.\" from FreeBSD: head/tools/build/options/WITH_GNU_SORT 237629 2012-06-27 
05:59:01Z gabor
+Install GNU-licensed sort as 'sort' instead of BSD sort.
 .It Va WITHOUT_GNU_SUPPORT
 .\" from FreeBSD: head/tools/build/options/WITHOUT_GNU_SUPPORT 156932 
2006-03-21 07:50:50Z ru
 Set to build some programs without optional GNU support.
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r237631 - head/sys/sys

2012-06-26 Thread Gabor Kovesdan
Author: gabor
Date: Wed Jun 27 06:08:02 2012
New Revision: 237631
URL: http://svn.freebsd.org/changeset/base/237631

Log:
  - Bump __FreeBSD_version: default sort is BSD sort

Modified:
  head/sys/sys/param.h

Modified: head/sys/sys/param.h
==
--- head/sys/sys/param.hWed Jun 27 06:00:58 2012(r237630)
+++ head/sys/sys/param.hWed Jun 27 06:08:02 2012(r237631)
@@ -58,7 +58,7 @@
  * in the range 5 to 9.
  */
 #undef __FreeBSD_version
-#define __FreeBSD_version 113  /* Master, propagated to newvers */
+#define __FreeBSD_version 114  /* Master, propagated to newvers */
 
 /*
  * __FreeBSD_kernel__ indicates that this system uses the kernel of FreeBSD,
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r237628 - head/usr.bin/sort

2012-06-26 Thread Eitan Adler
On 26 June 2012 22:50, Gabor Kovesdan  wrote:
> Author: gabor
> Date: Wed Jun 27 05:50:15 2012
> New Revision: 237628
> URL: http://svn.freebsd.org/changeset/base/237628
>
> Log:
>  - Disable threaded sort by default

Curious, why?

>  - Fix typo in the NLS support




--- head/sys/i386/i386/pmap.c   Wed Jun 27 03:24:27 2012(r237622)
+++ head/sys/i386/i386/pmap.c   Wed Jun 27 03:45:25 2012(r237623)
@@ -409,7 +409,7 @@ pmap_bootstrap(vm_paddr_t firstaddr)
/*
 * Initialize the global pv list lock.
 */
-   rw_init(&pvh_global_lock, "pvh global");
+   rw_init(&pvh_global_lock, "pmap pv global");
 
LIST_INIT(&allpmaps);
 

Modified: head/sys/kern/subr_witness.c
==
--- head/sys/kern/subr_witness.cWed Jun 27 03:24:27 2012
(r237622)
+++ head/sys/kern/subr_witness.cWed Jun 27 03:45:25 2012
(r237623)
@@ -593,19 +593,22 @@ static struct witness_order_list_entry o
/*
 * CDEV
 */
-   { "system map", &lock_class_mtx_sleep },
-   { "vm page queue mutex", &lock_class_mtx_sleep },
+   { "vm map (system)", &lock_class_mtx_sleep },
+   { "vm page queue", &lock_class_mtx_sleep },
{ "vnode interlock", &lock_class_mtx_sleep },
{ "cdev", &lock_class_mtx_sleep },
{ NULL, NULL },
/*
 * VM
-* 
 */
+   { "vm map (user)", &lock_class_sx },
{ "vm object", &lock_class_mtx_sleep },
-   { "page lock", &lock_class_mtx_sleep },
-   { "vm page queue mutex", &lock_class_mtx_sleep },
+   { "vm page", &lock_class_mtx_sleep },
+   { "vm page queue", &lock_class_mtx_sleep },
+   { "pmap pv global", &lock_class_rw },
{ "pmap", &lock_class_mtx_sleep },
+   { "pmap pv list", &lock_class_rw },
+   { "vm page free queue", &lock_class_mtx_sleep },
{ NULL, NULL },
/*
 * kqueue/VFS interaction

Modified: head/sys/sparc64/sparc64/pmap.c
==
--- head/sys/sparc64/sparc64/pmap.c Wed Jun 27 03:24:27 2012
(r237622)
+++ head/sys/sparc64/sparc64/pmap.c Wed Jun 27 03:45:25 2012
(r237623)
@@ -673,9 +673,10 @@ pmap_bootstrap(u_int cpu_impl)
CPU_FILL(&pm->pm_active);
 
/*
 * Initialize the global tte list lock.
 */
-   rw_init(&tte_list_global_lock, "tte list global");
+   rw_init(&tte_list_global_lock, "pmap pv global");
 
/*
 * Flush all non-locked TLB entries possibly left over by the
@@ -673,9 +673,10 @@ pmap_bootstrap(u_int cpu_impl)
 
/*
-* Initialize the global tte list lock.
+* Initialize the global tte list lock, which is more commonly
+* known as the pmap pv global lock.
 */

Modified: head/sys/vm/vm_map.c
==
-- 
Eitan Adler
Source & Ports committer
X11, Bugbusting teams
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"